i think the introspection mechanic is abit finicky

one failure mode:
    manager comes up with a plan and asks if its okay, but its not targetted at a recipient, so it gets sent back to them
    on self reflection, the agent can't tell that it sent the message to itself too also

